package com.ruoyi.llm.mapper;

import com.ruoyi.llm.domain.CmcAgent;

import java.util.List;

/**
 * 智能体Mapper接口
 * 
 * @author ruoyi
 * @date 2025-07-17
 */
public interface CmcAgentMapper 
{
    /**
     * 查询智能体
     * 
     * @param agentId 智能体主键
     * @return 智能体
     */
    public CmcAgent selectCmcAgentByAgentId(Integer agentId);

    /**
     * 查询智能体列表
     * 
     * @param cmcAgent 智能体
     * @return 智能体集合
     */
    public List<CmcAgent> selectCmcAgentList(CmcAgent cmcAgent);

    /**
     * 新增智能体
     * 
     * @param cmcAgent 智能体
     * @return 结果
     */
    public int insertCmcAgent(CmcAgent cmcAgent);

    /**
     * 修改智能体
     * 
     * @param cmcAgent 智能体
     * @return 结果
     */
    public int updateCmcAgent(CmcAgent cmcAgent);

    /**
     * 删除智能体
     * 
     * @param agentId 智能体主键
     * @return 结果
     */
    public int deleteCmcAgentByAgentId(Integer agentId);

    /**
     * 批量删除智能体
     * 
     * @param agentIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCmcAgentByAgentIds(Integer[] agentIds);
}
